@@ -1,4 +1,4 @@
-from typing import Dict, List, Optional, Set, Tuple, Union
+from typing import Dict, List, Optional, Tuple, Union
 
 from pydantic import BaseModel, HttpUrl
 
@@ -13,17 +13,17 @@ class Menu(BaseModel):
     # children menu
     children: Optional[List["Menu"]] = []
     # include fields
-    include: Optional[Tuple[str]]
+    include: Optional[Tuple[str, ...]] = tuple()
     # exclude fields
-    exclude: Optional[Tuple[str]]
+    exclude: Optional[Tuple[str, ...]] = tuple()
     # external link
     external: Optional[bool] = False
     # raw id fields
-    raw_id_fields: Optional[Tuple[str]] = set()
+    raw_id_fields: Optional[Tuple[str, ...]] = tuple()
     # searchable fields
-    search_fields: Optional[Tuple[str]] = set()
+    search_fields: Optional[Tuple[str, ...]] = tuple()
     # sortable fields
-    sort_fields: Optional[Set[str]] = set()
+    sort_fields: Optional[Tuple[str, ...]] = tuple()
     # define field type,like select,radiolist,text,date
     fields_type: Dict = {}
     # define field attr,like cols which in bootstrap table
